HRV_Shiny: Shiny App Function

HRV_ShinyR Documentation

Shiny App Function

Description

This function uses imported HRV data to generate a shiny app. Within the shiny app, the user can specify the time segment that they are interested in, and generate time domain HRV statistics based on that time segment. Within the app, time segments are specified to two decimal spaces (i.e., 3.50).

Usage

HRV_Shiny(imported_data, input)

Arguments

imported_data

Imported csv file containing a single column of MS or RR values.

input

Specify if the data imported data contains MS or RR values.

Value

Shiny


mrooyakkers/TimeDomainHRVSHINY documentation built on Jan. 12, 2023, 11:38 a.m.